@@ -24,6 +24,10 @@
 #endif
 #include <linux/serial.h>
 
+#ifndef PORT_16C950
+#define PORT_16C950	10	/* Oxford Semiconductor */
+#endif
+
 #define VERSION_STR "2.15"
 
 char *progname;
@@ -54,6 +58,9 @@ struct serial_type_struct {
 #endif
 #ifdef PORT_16750
 	PORT_16750,	"16750",
+#endif
+#ifdef PORT_16C950
+	PORT_16C950,	"16C950",
 #endif
 	PORT_UNKNOWN,	"none",
 	-1,		NULL
@@ -119,13 +126,12 @@ struct flag_type_table {
 	CMD_DELAY,	"close_delay",	0,		0,		0, FLAG_NEED_ARG,
 #ifdef ASYNC_CLOSING_WAIT_NONE
 	CMD_WAIT,	"closing_wait",	0,		0,		0, FLAG_NEED_ARG,
-	CMD_WAIT2,	"closing_wait2",0,		0,		0, FLAG_NEED_ARG,
 #endif
 	CMD_CONFIG,	"autoconfig",	0,		0,		0, 0,
 	CMD_CONFIG,	"autoconfigure",0,		0,		0, 0,
 	CMD_GETMULTI,	"get_multiport",0,		0,		0, 0,
 	CMD_SETMULTI,	"set_multiport",0,		0,		0, 0,
-#ifdef HAVE_LINUX_HAYESESP_H
+#ifdef TIOCGHAYESESP
 	CMD_RX_TRIG,    "rx_trigger",   0,              0,              0, FLAG_NEED_ARG,
 	CMD_TX_TRIG,    "tx_trigger",   0,              0,              0, FLAG_NEED_ARG,
 	CMD_FLOW_OFF,   "flow_off",     0,              0,              0, FLAG_NEED_ARG,
@@ -363,7 +369,7 @@ void set_multiport(char *device, int fd, char ***in_arg)
 }
 #endif
 
-#ifdef HAVE_LINUX_HAYESESP_H
+#ifdef TIOCGHAYESESP
 void print_hayesesp(int fd)
 {
 	struct hayes_esp_config esp;
@@ -423,7 +429,7 @@ void get_serial(char *device)
 {
 	struct serial_struct serinfo;
 	int	fd;
-	char	buf1[40], buf2[40];
+	char	buf1[40];
 
 	if ((fd = open(device, O_RDWR|O_NONBLOCK)) < 0) {
 		perror(device);
@@ -438,9 +444,9 @@ void get_serial(char *device)
 	if (serinfo.irq == 9)
 		serinfo.irq = 2;	/* People understand 2 better than 9 */
 	if (verbosity==-1) {
-		printf("%s uart %s port 0x%.4x irq %d", device,
+		printf("%s uart %s port 0x%.4x irq %d baud_base %d", device,
 		       serial_type(serinfo.type), serinfo.port,
-		       serinfo.irq);
+		       serinfo.irq, serinfo.baud_base);
 		print_flags(&serinfo, ", Flags: ", "");
 		printf("\n");
 	} else if (verbosity==2) {
@@ -457,18 +463,12 @@ void get_serial(char *device)
 			strcpy(buf1, "none");
 		else
 			sprintf(buf1, "%d", serinfo.closing_wait);
-		if (serinfo.closing_wait2 == ASYNC_CLOSING_WAIT_INF)
-			strcpy(buf2, "infinte");
-		else if (serinfo.closing_wait2 == ASYNC_CLOSING_WAIT_NONE)
-			strcpy(buf2, "none");
-		else
-			sprintf(buf2, "%d", serinfo.closing_wait2);
-		printf("\tclosing_wait: %s, closing_wait2: %s\n", buf1, buf2);
+		printf("\tclosing_wait: %s\n", buf1);
 #endif
 		print_flags(&serinfo, "\tFlags: ", "");
 		printf("\n\n");
 
-#ifdef HAVE_LINUX_HAYESESP_H
+#ifdef TIOCGHAYESESP
 		print_hayesesp(fd);
 #endif
 	} else if (verbosity==0) {
@@ -610,7 +610,7 @@ void set_serial(char *device, char ** arg)
 			}
 			set_multiport(device, fd, &arg);
 			break;
-#ifdef HAVE_LINUX_HAYESESP_H
+#ifdef TIOCGHAYESESP
 		case CMD_RX_TRIG:
 		case CMD_TX_TRIG:
 		case CMD_FLOW_OFF:
@@ -690,12 +690,7 @@ fprintf(stderr, "\t* port\t\tset the I/O port\n");
 #ifdef ASYNC_CLOSING_WAIT_NONE
 	fprintf(stderr, "\t* closing_wait\tset the amount of time (in 1/100 of a\n");
 	fprintf(stderr, "\t\t\t\tsecond) that the serial port should wait for\n");
-	fprintf(stderr, "\t\t\t\tdata to be drained while being closed, \n");
-	fprintf(stderr, "\t\t\t\tbefore the reciver is disabled\n");
-	fprintf(stderr, "\t* closing_wait2\tset the amount of time (in 1/100 of a\n");
-	fprintf(stderr, "\t\t\t\tsecond) that the serial port should wait for\n");
-	fprintf(stderr, "\t\t\t\tdata to be drained while being closed, \n");
-	fprintf(stderr, "\t\t\t\tafter the reciver is disabled\n");
+	fprintf(stderr, "\t\t\t\tdata to be drained while being closed.\n");
 #endif
 	fprintf(stderr, "\t^ fourport\tconfigure the port as an AST Fourport\n");
 	fprintf(stderr, "\t  autoconfig\tautomatically configure the serial port\n");
@@ -722,13 +717,13 @@ fprintf(stderr, "\t* port\t\tset the I/O port\n");
 	fprintf(stderr, "\t  get_multiport\tDisplay the multiport configuration\n");
 	fprintf(stderr, "\t  set_multiport\tSet the multiport configuration\n");
 	fprintf(stderr, "\n");
-#ifdef HAVE_LINUX_HAYESESP_H
-	fprintf(stderr, "\t* rx_trigger\tSet RX trigger level\n");
-	fprintf(stderr, "\t* tx_trigger\tSet TX trigger level\n");
-	fprintf(stderr, "\t* flow_off\tSet hardware flow off level\n");
-	fprintf(stderr, "\t* flow_on\tSet hardware flow on level\n");
-	fprintf(stderr, "\t* rx_timeout\tSet receive timeout\n");
-	fprintf(stderr, "\t* dma_channel\tSet DMA channel");
+#ifdef TIOCGHAYESESP
+	fprintf(stderr, "\t* rx_trigger\tSet RX trigger level (ESP-only)\n");
+	fprintf(stderr, "\t* tx_trigger\tSet TX trigger level (ESP-only)\n");
+	fprintf(stderr, "\t* flow_off\tSet hardware flow off level (ESP-only)\n");
+	fprintf(stderr, "\t* flow_on\tSet hardware flow on level (ESP-only)\n");
+	fprintf(stderr, "\t* rx_timeout\tSet receive timeout (ESP-only)\n");
+	fprintf(stderr, "\t* dma_channel\tSet DMA channel (ESP-only)\n");
 #endif
 	fprintf(stderr, "\n");
 	fprintf(stderr, "\t  spd_hi\tuse 56kb instead of 38.4kb\n");
