@@ -5,5 +5,5 @@
  * redistributed under the GNU Public License.
  */
 
-#define SETSERIAL_VERSION "2.15"
-#define SETSERIAL_DATE "2-Nov-98"
+#define SETSERIAL_VERSION "2.16"
+#define SETSERIAL_DATE "8-Mar-99"
